# The software in this package is distributed under the GNU General
# Public License version 2 (with a special exception described below).
#
# A copy of GNU General Public License (GPL) is included in this distribution,
# in the file COPYING.GPL.
#
# As a special exception, if other files instantiate templates or use macros
# or inline functions from this file, or you compile this file and link it
# with other works to produce a work based on this file, this file
# does not by itself cause the resulting work to be covered
# by the GNU General Public License.
#
# However the source code for this file must still be made available
# in accordance with section (3) of the GNU General Public License.
#
# This exception does not invalidate any other reasons why a work based
# on this file might be covered by the GNU General Public License.
#
# Copyright (c) 2016-2018 Intra2net AG <info@intra2net.com>

"""
Helpers for type checking and conversion, like isstr(x), is_file_obj(x)
"""

import sys
from io import IOBase


def isstr(var):
    """ determines if the given var is a (regular/unicode/raw) string or not

    in python2, u'a' is not a subclass of str, so to get a True as result, you
      have to test for basestring as superclass.

    In python3 that is no longer the case

    @returns True if the input is a regular string, a unicode or a raw string,
       False for everything else (including byte literals like b'abc')

    For more complex py2/py3 compatibility issues, consider using six
      (https://pythonhosted.org/six)
    """

    return isinstance(var, str)


def is_str_or_byte(var):
    """ returns true for str, unicode and byte objects """
    return isinstance(var, (str, bytes))


def is_unicode(var):
    """ returns true for unicode strings

    py2: return True for type unicode but not type str
    py3: return True for type str but not type bytes
    """
    return isinstance(var, str)


def is_file_obj(var):
    """ determines whether given input is the result of 'open(file_name)'

    just checks whether given var is subclass of io.IOBase, which is also True
    for 'file-like objects' like StringIO
    """
    return isinstance(var, IOBase)
